aboutsummaryrefslogtreecommitdiff
path: root/engine/lib/usersettings.php
diff options
context:
space:
mode:
Diffstat (limited to 'engine/lib/usersettings.php')
-rw-r--r--engine/lib/usersettings.php4
1 files changed, 2 insertions, 2 deletions
diff --git a/engine/lib/usersettings.php b/engine/lib/usersettings.php
index 24a956a62..4843ffc99 100644
--- a/engine/lib/usersettings.php
+++ b/engine/lib/usersettings.php
@@ -20,14 +20,14 @@
* nb. some pages already exist that you can extend), extend the main view to point to it, and add controls to your
* new view.
*
* At the moment this is essentially a wrapper around extend_view.
*
* @param string $new_settings_view The view associated with the control you're adding
* @param string $view The view to extend, by default this is 'usersettings/main'.
* @param int $priority Optional priority to govern the appearance in the list.
*/
function extend_elgg_settings_page( $new_settings_view, $view = 'usersettings/main', $priority = 500) {
- return extend_view($view, $new_settings_view, $priority);
+ return elgg_extend_view($view, $new_settings_view, $priority);
}
function usersettings_pagesetup() {
@@ -20,14 +20,14 @@
* new view.
*
- * At the moment this is essentially a wrapper around extend_view.
+ * At the moment this is essentially a wrapper around elgg_extend_view().
*
* @param string $new_settings_view The view associated with the control you're adding